@@ -19,8 +19,28 @@ from evalml.automl.automl_algorithm import IterativeAlgorithm
 from evalml.automl.data_splitters import TrainingValidationSplit
 from evalml.data_checks import DataChecks, DefaultDataChecks, EmptyDataChecks
 from evalml.data_checks.data_check_message_type import DataCheckMessageType
-from evalml.exceptions import PipelineNotFoundError, PipelineScoreError
-from evalml.objectives import get_objective, get_objectives
+from evalml.exceptions import (
+    AutoMLSearchException,
+    PipelineNotFoundError,
+    PipelineScoreError
+)
+from evalml.objectives import (
+    CostBenefitMatrix,
+    FraudCost,
+    LeadScoring,
+    MeanSquaredLogError,
+    Recall,
+    RecallMacro,
+    RecallMicro,
+    RecallWeighted,
+    RootMeanSquaredLogError,
+    get_objective,
+    get_objectives
+)
+from evalml.objectives.utils import (
+    _all_objectives_dict,
+    _print_objectives_in_table
+)
 from evalml.pipelines import (
     BinaryClassificationPipeline,
     MeanBaselineRegressionPipeline,
@@ -32,6 +52,7 @@ from evalml.pipelines.utils import make_pipeline
 from evalml.problem_types import ProblemTypes, handle_problem_types
 from evalml.tuners import SKOptTuner
 from evalml.utils import convert_to_seconds, get_random_state
+from evalml.utils.gen_utils import classproperty
 from evalml.utils.logger import (
     get_logger,
     log_subtitle,
@@ -51,9 +72,9 @@ class AutoMLSearch:
     # Necessary for "Plotting" documentation, since Sphinx does not work well with instance attributes.
     plot = PipelineSearchPlots
 
-    _DEFAULT_OBJECTIVES = {'binary': 'log_loss_binary',
-                           'multiclass': 'log_loss_multi',
-                           'regression': 'r2'}
+    _DEFAULT_OBJECTIVES = {'binary': 'Log Loss Binary',
+                           'multiclass': 'Log Loss Multiclass',
+                           'regression': 'R2'}
 
     def __init__(self,
                  problem_type=None,
@@ -72,7 +93,8 @@ class AutoMLSearch:
                  n_jobs=-1,
                  tuner_class=None,
                  verbose=True,
-                 optimize_thresholds=False):
+                 optimize_thresholds=False,
+                 _max_batches=None):
         """Automated pipeline search
 
         Arguments:
@@ -111,10 +133,10 @@ class AutoMLSearch:
             tuner_class: the tuner class to use. Defaults to scikit-optimize tuner
 
             start_iteration_callback (callable): function called before each pipeline training iteration.
-                Passed two parameters: pipeline_class, parameters.
+                Passed three parameters: pipeline_class, parameters, and the AutoMLSearch object.
 
             add_result_callback (callable): function called after each pipeline training iteration.
-                Passed two parameters: results, trained_pipeline.
+                Passed three parameters: A dictionary containing the training results for the new pipeline, an untrained_pipeline containing the parameters used during training, and the AutoMLSearch object.
 
             additional_objectives (list): Custom set of objectives to score on.
                 Will override default objectives for problem type if not empty.
@@ -125,6 +147,9 @@ class AutoMLSearch:
                 None and 1 are equivalent. If set to -1, all CPUs are used. For n_jobs below -1, (n_cpus + 1 + n_jobs) are used.
 
             verbose (boolean): If True, turn verbosity on. Defaults to True
+
+            _max_batches (int): The maximum number of batches of pipelines to search. Parameters max_time, and
+                max_pipelines have precedence over stopping the search.
         """
         try:
             self.problem_type = handle_problem_types(problem_type)
@@ -139,19 +164,21 @@ class AutoMLSearch:
         self.optimize_thresholds = optimize_thresholds
         if objective == 'auto':
             objective = self._DEFAULT_OBJECTIVES[self.problem_type.value]
-        self.objective = get_objective(objective)
+        objective = get_objective(objective, return_instance=False)
+        self.objective = self._validate_objective(objective)
         if self.data_split is not None and not issubclass(self.data_split.__class__, BaseCrossValidator):
             raise ValueError("Not a valid data splitter")
         if self.problem_type != self.objective.problem_type:
             raise ValueError("Given objective {} is not compatible with a {} problem.".format(self.objective.name, self.problem_type.value))
         if additional_objectives is None:
-            additional_objectives = get_objectives(self.problem_type)
+            additional_objectives = [obj for obj in get_objectives(self.problem_type) if obj not in self._objectives_not_allowed_in_automl]
             # if our main objective is part of default set of objectives for problem_type, remove it
             existing_main_objective = next((obj for obj in additional_objectives if obj.name == self.objective.name), None)
             if existing_main_objective is not None:
                 additional_objectives.remove(existing_main_objective)
         else:
             additional_objectives = [get_objective(o) for o in additional_objectives]
+        additional_objectives = [self._validate_objective(obj) for obj in additional_objectives]
         self.additional_objectives = additional_objectives
 
         if max_time is None or isinstance(max_time, (int, float)):
@@ -162,7 +189,7 @@ class AutoMLSearch:
             raise TypeError("max_time must be a float, int, or string. Received a {}.".format(type(max_time)))
 
         self.max_pipelines = max_pipelines
-        if self.max_pipelines is None and self.max_time is None:
+        if self.max_pipelines is None and self.max_time is None and _max_batches is None:
             self.max_pipelines = 5
             logger.info("Using default limit of max_pipelines=5.\n")
 
@@ -193,16 +220,43 @@ class AutoMLSearch:
         self.allowed_model_families = allowed_model_families
         self._automl_algorithm = None
         self._start = None
+        self._baseline_cv_score = None
+
+        if _max_batches is not None and _max_batches <= 0:
+            raise ValueError("Parameter max batches must be None or non-negative. Received {max_batches}.")
+        self._max_batches = _max_batches
+        # This is the default value for IterativeAlgorithm - setting this explicitly makes sure that
+        # the behavior of max_batches does not break if IterativeAlgorithm is changed.
+        self._pipelines_per_batch = 5
 
         self._validate_problem_type()
 
+    @classproperty
+    def _objectives_not_allowed_in_automl(self):
+        return {CostBenefitMatrix, FraudCost, LeadScoring,
+                MeanSquaredLogError, Recall, RecallMacro, RecallMicro, RecallWeighted, RootMeanSquaredLogError}
+
+    @classmethod
+    def print_objective_names_allowed_in_automl(cls):
+        names = [name for name, value in _all_objectives_dict().items() if value not in cls._objectives_not_allowed_in_automl]
+        _print_objectives_in_table(names)
+
+    def _validate_objective(self, objective):
+        if isinstance(objective, type):
+            if objective in self._objectives_not_allowed_in_automl:
+                raise ValueError(f"{objective.name} is not allowed in AutoML! "
+                                 "Use evalml.automl.AutoMLSearch.print_objective_names_allowed_in_automl() "
+                                 "to get all objective names allowed in automl.")
+            return objective()
+        return objective
+
     @property
     def data_check_results(self):
         return self._data_check_results
 
     def __str__(self):
         def _print_list(obj_list):
-            lines = ['\t{}'.format(o.name) for o in obj_list]
+            lines = sorted(['\t{}'.format(o.name) for o in obj_list])
             return '\n'.join(lines)
 
         def _get_funct_name(function):
@@ -360,6 +414,8 @@ class AutoMLSearch:
 
         if self.allowed_pipelines == []:
             raise ValueError("No allowed pipelines to search")
+        if self._max_batches and self.max_pipelines is None:
+            self.max_pipelines = 1 + len(self.allowed_pipelines) + (self._pipelines_per_batch * (self._max_batches - 1))
 
         self.allowed_model_families = list(set([p.model_family for p in (self.allowed_pipelines)]))
 
@@ -372,7 +428,8 @@ class AutoMLSearch:
             tuner_class=self.tuner_class,
             random_state=self.random_state,
             n_jobs=self.n_jobs,
-            number_features=X.shape[1]
+            number_features=X.shape[1],
+            pipelines_per_batch=self._pipelines_per_batch
         )
 
         log_title(logger, "Beginning pipeline search")
@@ -395,11 +452,15 @@ class AutoMLSearch:
             return
 
         current_batch_pipelines = []
+        current_batch_pipeline_scores = []
         while self._check_stopping_condition(self._start):
             try:
                 if len(current_batch_pipelines) == 0:
                     try:
+                        if current_batch_pipeline_scores and np.isnan(np.array(current_batch_pipeline_scores, dtype=float)).all():
+                            raise AutoMLSearchException(f"All pipelines in the current AutoML batch produced a score of np.nan on the primary objective {self.objective}.")
                         current_batch_pipelines = self._automl_algorithm.next_batch()
+                        current_batch_pipeline_scores = []
                     except StopIteration:
                         logger.info('AutoML Algorithm out of recommendations, ending')
                         break
@@ -409,7 +470,7 @@ class AutoMLSearch:
                 logger.debug('Pipeline parameters: {}'.format(parameters))
 
                 if self.start_iteration_callback:
-                    self.start_iteration_callback(pipeline.__class__, parameters)
+                    self.start_iteration_callback(pipeline.__class__, parameters, self)
                 desc = f"{pipeline.name}"
                 if len(desc) > self._MAX_NAME_LEN:
                     desc = desc[:self._MAX_NAME_LEN - 3] + "..."
@@ -420,6 +481,7 @@ class AutoMLSearch:
                 evaluation_results = self._evaluate(pipeline, X, y)
                 score = evaluation_results['cv_score_mean']
                 score_to_minimize = -score if self.objective.greater_is_better else score
+                current_batch_pipeline_scores.append(score_to_minimize)
                 self._automl_algorithm.add_result(score_to_minimize, pipeline)
 
                 if search_iteration_plot:
@@ -508,7 +570,7 @@ class AutoMLSearch:
         while pipelines:
             try:
                 if self.start_iteration_callback:
-                    self.start_iteration_callback(baseline.__class__, baseline.parameters)
+                    self.start_iteration_callback(baseline.__class__, baseline.parameters, self)
                 baseline = pipelines.pop()
                 desc = f"{baseline.name}"
                 if len(desc) > self._MAX_NAME_LEN:
@@ -519,6 +581,7 @@ class AutoMLSearch:
                                 self._start)
 
                 baseline_results = self._compute_cv_scores(baseline, X, y)
+                self._baseline_cv_score = baseline_results["cv_score_mean"]
                 self._add_result(trained_pipeline=baseline,
                                  parameters=baseline.parameters,
                                  training_time=baseline_results['training_time'],
@@ -544,7 +607,6 @@ class AutoMLSearch:
             try:
                 X_threshold_tuning = None
                 y_threshold_tuning = None
-
                 if self.optimize_thresholds and self.objective.problem_type == ProblemTypes.BINARY and self.objective.can_optimize_threshold:
                     X_train, X_threshold_tuning, y_train, y_threshold_tuning = train_test_split(X_train, y_train, test_size=0.2, random_state=self.random_state)
                 cv_pipeline = pipeline.clone()
@@ -605,6 +667,7 @@ class AutoMLSearch:
 
     def _add_result(self, trained_pipeline, parameters, training_time, cv_data, cv_scores):
         cv_score = cv_scores.mean()
+        percent_better = self.objective.calculate_percent_difference(cv_score, self._baseline_cv_score)
         # calculate high_variance_cv
         # if the coefficient of variance is greater than .2
         with warnings.catch_warnings():
@@ -625,11 +688,12 @@ class AutoMLSearch:
             "high_variance_cv": high_variance_cv,
             "training_time": training_time,
             "cv_data": cv_data,
+            "percent_better_than_baseline": percent_better
         }
         self._results['search_order'].append(pipeline_id)
 
         if self.add_result_callback:
-            self.add_result_callback(self._results['pipeline_results'][pipeline_id], trained_pipeline)
+            self.add_result_callback(self._results['pipeline_results'][pipeline_id], trained_pipeline, self)
 
     def _evaluate(self, pipeline, X, y):
         parameters = pipeline.parameters
@@ -771,7 +835,8 @@ class AutoMLSearch:
         if self.objective.greater_is_better:
             ascending = False
 
-        full_rankings_cols = ["id", "pipeline_name", "score", "high_variance_cv", "parameters"]
+        full_rankings_cols = ["id", "pipeline_name", "score", "percent_better_than_baseline",
+                              "high_variance_cv", "parameters"]
         if not self.has_searched:
             return pd.DataFrame(columns=full_rankings_cols)
 
@@ -794,17 +859,18 @@ class AutoMLSearch:
         best = self.rankings.iloc[0]
         return self.get_pipeline(best["id"])
 
-    def save(self, file_path):
+    def save(self, file_path, pickle_protocol=cloudpickle.DEFAULT_PROTOCOL):
         """Saves AutoML object at file path
 
         Arguments:
             file_path (str): location to save file
+            pickle_protocol (int): the pickle data stream format.
 
         Returns:
             None
         """
         with open(file_path, 'wb') as f:
-            cloudpickle.dump(self, f)
+            cloudpickle.dump(self, f, protocol=pickle_protocol)
 
     @staticmethod
     def load(file_path):
