@@ -3,7 +3,7 @@ from sklearn.datasets import load_breast_cancer as load_breast_cancer_sk
 
 
 def load_breast_cancer():
-    """Load breast cancer dataset. Multiclass problem
+    """Load breast cancer dataset. Binary classification problem.
 
     Returns:
         pd.DataFrame, pd.Series: X, y
