@@ -1,5 +1,6 @@
 # flake8:noqa
 from .binary_classification_objective import BinaryClassificationObjective
+from .cost_benefit_matrix import CostBenefitMatrix
 from .fraud_cost import FraudCost
 from .lead_scoring import LeadScoring
 from .multiclass_classification_objective import (
@@ -42,4 +43,4 @@ from .standard_metrics import (
     RecallMicro,
     RecallWeighted
 )
-from .utils import get_objective, get_objectives
+from .utils import get_objective, get_objectives, print_all_objective_names
