@@ -1,3 +1,5 @@
+import math
+
 import pandas as pd
 
 from .binary_classification_objective import BinaryClassificationObjective
@@ -8,6 +10,7 @@ class LeadScoring(BinaryClassificationObjective):
     name = "Lead Scoring"
     greater_is_better = True
     score_needs_proba = False
+    perfect_score = math.inf
 
     def __init__(self, true_positives=1, false_positives=-1):
         """Create instance.
