@@ -6,6 +6,7 @@ from .components import (
     PerColumnImputer,
     StandardScaler,
     Transformer,
+    LightGBMClassifier,
     LinearRegressor,
     LogisticRegressionClassifier,
     RandomForestClassifier,
@@ -13,7 +14,6 @@ from .components import (
     XGBoostClassifier,
     XGBoostRegressor,
     FeatureSelector,
-    CategoricalEncoder,
     RFClassifierSelectFromModel,
     RFRegressorSelectFromModel,
     CatBoostClassifier,
@@ -41,15 +41,3 @@ from .regression import (
     BaselineRegressionPipeline,
     MeanBaselineRegressionPipeline
 )
-
-from .graph_utils import (
-    precision_recall_curve,
-    graph_precision_recall_curve,
-    roc_curve,
-    graph_roc_curve,
-    confusion_matrix,
-    normalize_confusion_matrix,
-    graph_confusion_matrix,
-    calculate_permutation_importance,
-    graph_permutation_importance
-)
