@@ -25,7 +25,7 @@ class BinaryClassificationPipeline(ClassificationPipeline):
         X_t = self._transform(X)
 
         if objective is not None:
-            objective = get_objective(objective)
+            objective = get_objective(objective, return_instance=True)
             if objective.problem_type != self.problem_type:
                 raise ValueError("You can only use a binary classification objective to make predictions for a binary classification pipeline.")
 
