@@ -3,6 +3,7 @@ from .component_base import ComponentBase, ComponentBaseMeta
 from .estimators import (
     Estimator,
     LinearRegressor,
+    LightGBMClassifier,
     LogisticRegressionClassifier,
     RandomForestClassifier,
     RandomForestRegressor,
@@ -27,10 +28,10 @@ from .transformers import (
     Imputer,
     StandardScaler,
     FeatureSelector,
-    CategoricalEncoder,
     DropColumns,
     DropNullColumns,
     DateTimeFeaturizer,
     SelectColumns,
-    TextFeaturizer
+    TextFeaturizer,
+    LSA,
     )
