@@ -1,12 +1,12 @@
 import copy
-from abc import ABC, ABCMeta, abstractmethod
-from functools import wraps
+from abc import ABC, abstractmethod
 
-from evalml.exceptions import (
-    ComponentNotYetFittedError,
-    MethodPropertyNotFoundError
-)
+import cloudpickle
+
+from evalml.exceptions import MethodPropertyNotFoundError
+from evalml.pipelines.components.component_base_meta import ComponentBaseMeta
 from evalml.utils import (
+    check_random_state_equality,
     classproperty,
     get_logger,
     get_random_state,
@@ -16,57 +16,6 @@ from evalml.utils import (
 logger = get_logger(__file__)
 
 
-class ComponentBaseMeta(ABCMeta):
-    """Metaclass that overrides creating a new component by wrapping method with validators and setters"""
-    from evalml.exceptions import ComponentNotYetFittedError
-
-    NO_FITTING_REQUIRED = ['DropColumns', 'SelectColumns']
-
-    @classmethod
-    def set_fit(cls, method):
-        @wraps(method)
-        def _set_fit(self, X, y=None):
-            return_value = method(self, X, y)
-            self._is_fitted = True
-            return return_value
-        return _set_fit
-
-    @classmethod
-    def check_for_fit(cls, method):
-        """`check_for_fit` wraps a method that validates if `self._is_fitted` is `True`.
-            It raises an exception if `False` and calls and returns the wrapped method if `True`.
-        """
-        @wraps(method)
-        def _check_for_fit(self, X=None, y=None):
-            klass = type(self).__name__
-            if not self._is_fitted and klass not in cls.NO_FITTING_REQUIRED:
-                raise ComponentNotYetFittedError(f'This {klass} is not fitted yet. You must fit {klass} before calling {method.__name__}.')
-            elif X is None and y is None:
-                return method(self)
-            elif y is None:
-                return method(self, X)
-            else:
-                return method(self, X, y)
-        return _check_for_fit
-
-    def __new__(cls, name, bases, dct):
-        if 'predict' in dct:
-            dct['predict'] = cls.check_for_fit(dct['predict'])
-        if 'predict_proba' in dct:
-            dct['predict_proba'] = cls.check_for_fit(dct['predict_proba'])
-        if 'transform' in dct:
-            dct['transform'] = cls.check_for_fit(dct['transform'])
-        if 'feature_importance' in dct:
-            fi = dct['feature_importance']
-            new_fi = property(cls.check_for_fit(fi.__get__), fi.__set__, fi.__delattr__)
-            dct['feature_importance'] = new_fi
-        if 'fit' in dct:
-            dct['fit'] = cls.set_fit(dct['fit'])
-        if 'fit_transform' in dct:
-            dct['fit_transform'] = cls.set_fit(dct['fit_transform'])
-        return super().__new__(cls, name, bases, dct)
-
-
 class ComponentBase(ABC, metaclass=ComponentBaseMeta):
     """Base class for all components."""
     _default_parameters = None
@@ -89,6 +38,14 @@ class ComponentBase(ABC, metaclass=ComponentBaseMeta):
     def model_family(cls):
         """Returns ModelFamily of this component"""
 
+    @classproperty
+    def needs_fitting(self):
+        """Returns boolean determining if component needs fitting before
+            calling predict, predict_proba, transform, or feature_importances.
+            This can be overridden to False for components that do not need to be fit
+            or whose fit methods do nothing."""
+        return True
+
     @property
     def parameters(self):
         """Returns the parameters which were used to initialize the component"""
@@ -156,3 +113,41 @@ class ComponentBase(ABC, metaclass=ComponentBaseMeta):
             component_dict = {"name": self.name}
             component_dict.update({"parameters": self.parameters})
             return component_dict
+
+    def save(self, file_path, pickle_protocol=cloudpickle.DEFAULT_PROTOCOL):
+        """Saves component at file path
+
+        Arguments:
+            file_path (str): location to save file
+            pickle_protocol (int): the pickle data stream format.
+
+        Returns:
+            None
+        """
+        with open(file_path, 'wb') as f:
+            cloudpickle.dump(self, f, protocol=pickle_protocol)
+
+    @staticmethod
+    def load(file_path):
+        """Loads component at file path
+
+        Arguments:
+            file_path (str): location to load file
+
+        Returns:
+            ComponentBase object
+        """
+        with open(file_path, 'rb') as f:
+            return cloudpickle.load(f)
+
+    def __eq__(self, other):
+        if not isinstance(other, self.__class__):
+            return False
+        random_state_eq = check_random_state_equality(self.random_state, other.random_state)
+        if not random_state_eq:
+            return False
+        attributes_to_check = ['_parameters', '_is_fitted']
+        for attribute in attributes_to_check:
+            if getattr(self, attribute) != getattr(other, attribute):
+                return False
+        return True
