@@ -1,4 +1,5 @@
 import copy
+import warnings
 
 import numpy as np
 import pandas as pd
@@ -9,6 +10,7 @@ from evalml.model_family import ModelFamily
 from evalml.pipelines.components.estimators import Estimator
 from evalml.problem_types import ProblemTypes
 from evalml.utils import SEED_BOUNDS, get_random_seed, import_or_raise
+from evalml.utils.gen_utils import categorical_dtypes
 
 
 class CatBoostClassifier(Estimator):
@@ -30,12 +32,17 @@ class CatBoostClassifier(Estimator):
     SEED_MIN = 0
     SEED_MAX = SEED_BOUNDS.max_bound
 
-    def __init__(self, n_estimators=10, eta=0.03, max_depth=6, bootstrap_type=None, random_state=0, **kwargs):
+    def __init__(self, n_estimators=10, eta=0.03, max_depth=6, bootstrap_type=None, silent=True,
+                 random_state=0, **kwargs):
         random_seed = get_random_seed(random_state, self.SEED_MIN, self.SEED_MAX)
         parameters = {"n_estimators": n_estimators,
                       "eta": eta,
                       "max_depth": max_depth,
-                      'bootstrap_type': bootstrap_type}
+                      'bootstrap_type': bootstrap_type,
+                      'silent': silent}
+        if kwargs.get('allow_writing_files', False):
+            warnings.warn("Parameter allow_writing_files is being set to False in CatBoostClassifier")
+        kwargs["allow_writing_files"] = False
         parameters.update(kwargs)
 
         cb_error_msg = "catboost is not installed. Please install using `pip install catboost.`"
@@ -46,9 +53,7 @@ class CatBoostClassifier(Estimator):
         if bootstrap_type is None:
             cb_parameters.pop('bootstrap_type')
         cb_classifier = catboost.CatBoostClassifier(**cb_parameters,
-                                                    random_seed=random_seed,
-                                                    silent=True,
-                                                    allow_writing_files=False)
+                                                    random_seed=random_seed)
         super().__init__(parameters=parameters,
                          component_obj=cb_classifier,
                          random_state=random_state)
@@ -58,7 +63,7 @@ class CatBoostClassifier(Estimator):
             X = pd.DataFrame(X)
         if not isinstance(y, pd.Series):
             y = pd.Series(y)
-        cat_cols = X.select_dtypes(['category', 'object'])
+        cat_cols = X.select_dtypes(categorical_dtypes)
 
         # For binary classification, catboost expects numeric values, so encoding before.
         if y.nunique() <= 2:
