@@ -1,7 +1,7 @@
 import pandas as pd
-from sklearn.impute import SimpleImputer as SkImputer
 
 from evalml.pipelines.components.transformers import Transformer
+from evalml.pipelines.components.transformers.imputers import SimpleImputer
 from evalml.utils.gen_utils import boolean, categorical_dtypes, numeric_dtypes
 
 
@@ -16,15 +16,17 @@ class Imputer(Transformer):
     _valid_numeric_impute_strategies = set(["mean", "median", "most_frequent", "constant"])
 
     def __init__(self, categorical_impute_strategy="most_frequent",
+                 categorical_fill_value=None,
                  numeric_impute_strategy="mean",
-                 fill_value=None, random_state=0, **kwargs):
+                 numeric_fill_value=None,
+                 random_state=0, **kwargs):
         """Initalizes an transformer that imputes missing data according to the specified imputation strategy."
 
         Arguments:
             categorical_impute_strategy (string): Impute strategy to use for string, object, boolean, categorical dtypes. Valid values include "most_frequent" and "constant".
             numeric_impute_strategy (string): Impute strategy to use for numeric dtypes. Valid values include "mean", "median", "most_frequent", and "constant".
-            fill_value (string): When impute_strategy == "constant", fill_value is used to replace missing data.
-               Defaults to 0 when imputing  data and "missing_value" for strings or object data types.
+            categorical_fill_value (string): When categorical_impute_strategy == "constant", fill_value is used to replace missing data. The default value of None will fill with the string "missing_value".
+            numeric_fill_value (int, float): When numeric_impute_strategy == "constant", fill_value is used to replace missing data. The default value of None will fill with 0.
         """
         if categorical_impute_strategy not in self._valid_categorical_impute_strategies:
             raise ValueError(f"{categorical_impute_strategy} is an invalid parameter. Valid categorical impute strategies are {', '.join(self._valid_numeric_impute_strategies)}")
@@ -33,14 +35,15 @@ class Imputer(Transformer):
 
         parameters = {"categorical_impute_strategy": categorical_impute_strategy,
                       "numeric_impute_strategy": numeric_impute_strategy,
-                      "fill_value": fill_value}
+                      "categorical_fill_value": categorical_fill_value,
+                      "numeric_fill_value": numeric_fill_value}
         parameters.update(kwargs)
-        self._categorical_imputer = SkImputer(strategy=categorical_impute_strategy,
-                                              fill_value=fill_value,
+        self._categorical_imputer = SimpleImputer(impute_strategy=categorical_impute_strategy,
+                                                  fill_value=categorical_fill_value,
+                                                  **kwargs)
+        self._numeric_imputer = SimpleImputer(impute_strategy=numeric_impute_strategy,
+                                              fill_value=numeric_fill_value,
                                               **kwargs)
-        self._numeric_imputer = SkImputer(strategy=numeric_impute_strategy,
-                                          fill_value=fill_value,
-                                          **kwargs)
         self._all_null_cols = None
         self._numeric_cols = None
         self._categorical_cols = None
@@ -49,7 +52,8 @@ class Imputer(Transformer):
                          random_state=random_state)
 
     def fit(self, X, y=None):
-        """Fits imputer to data
+        """Fits imputer to data. 'None' values are converted to np.nan before imputation and are
+            treated as the same.
 
         Arguments:
             X (pd.DataFrame or np.array): the input training data of shape [n_samples, n_features]
@@ -77,7 +81,8 @@ class Imputer(Transformer):
         return self
 
     def transform(self, X, y=None):
-        """Transforms data X by imputing missing values
+        """Transforms data X by imputing missing values. 'None' values are converted to np.nan before imputation and are
+            treated as the same.
 
         Arguments:
             X (pd.DataFrame): Data to transform
@@ -87,20 +92,18 @@ class Imputer(Transformer):
         """
         if not isinstance(X, pd.DataFrame):
             X = pd.DataFrame(X)
-
         X_null_dropped = X.copy()
         X_null_dropped.drop(self._all_null_cols, inplace=True, axis=1, errors='ignore')
+        X_null_dropped.reset_index(inplace=True, drop=True)
         if X_null_dropped.empty:
             return X_null_dropped
-        dtypes = X_null_dropped.dtypes.to_dict()
 
         if self._numeric_cols is not None and len(self._numeric_cols) > 0:
             X_numeric = X_null_dropped[self._numeric_cols]
             X_null_dropped[X_numeric.columns] = self._numeric_imputer.transform(X_numeric)
+
         if self._categorical_cols is not None and len(self._categorical_cols) > 0:
             X_categorical = X_null_dropped[self._categorical_cols]
             X_null_dropped[X_categorical.columns] = self._categorical_imputer.transform(X_categorical)
 
-        transformed = X_null_dropped.astype(dtypes)
-        transformed.reset_index(inplace=True, drop=True)
-        return transformed
+        return X_null_dropped
