@@ -1,5 +1,4 @@
-import warnings
-
+import numpy as np
 import pandas as pd
 from sklearn.impute import SimpleImputer as SkImputer
 
@@ -20,8 +19,6 @@ class SimpleImputer(Transformer):
             fill_value (string): When impute_strategy == "constant", fill_value is used to replace missing data.
                Defaults to 0 when imputing numerical data and "missing_value" for strings or object data types.
         """
-        warnings.warn("SimpleImputer is deprecated in v0.12.0 and will be removed in 0.13.0 in favor of Imputer", DeprecationWarning)
-
         parameters = {"impute_strategy": impute_strategy,
                       "fill_value": fill_value}
         parameters.update(kwargs)
@@ -34,7 +31,8 @@ class SimpleImputer(Transformer):
                          random_state=random_state)
 
     def fit(self, X, y=None):
-        """Fits imputer to data
+        """Fits imputer to data. 'None' values are converted to np.nan before imputation and are
+            treated as the same.
 
         Arguments:
             X (pd.DataFrame or np.array): the input training data of shape [n_samples, n_features]
@@ -45,12 +43,16 @@ class SimpleImputer(Transformer):
         """
         if not isinstance(X, pd.DataFrame):
             X = pd.DataFrame(X)
+        # Convert None to np.nan, since None cannot be properly handled
+        X = X.fillna(value=np.nan)
+
         self._component_obj.fit(X, y)
         self._all_null_cols = set(X.columns) - set(X.dropna(axis=1, how='all').columns)
         return self
 
     def transform(self, X, y=None):
-        """Transforms data X by imputing missing values
+        """Transforms data X by imputing missing values. 'None' values are converted to np.nan before imputation and are
+            treated as the same.
 
         Arguments:
             X (pd.DataFrame): Data to transform
@@ -58,19 +60,24 @@ class SimpleImputer(Transformer):
         Returns:
             pd.DataFrame: Transformed X
         """
+        if not isinstance(X, pd.DataFrame):
+            X = pd.DataFrame(X)
+        # Convert None to np.nan, since None cannot be properly handled
+        X = X.fillna(value=np.nan)
 
+        X_null_dropped = X.copy()
+        X_null_dropped.drop(self._all_null_cols, axis=1, errors='ignore', inplace=True)
+        category_cols = X_null_dropped.select_dtypes(include=['category']).columns
         X_t = self._component_obj.transform(X)
-        if not isinstance(X_t, pd.DataFrame) and isinstance(X, pd.DataFrame):
-            # skLearn's SimpleImputer loses track of column type, so we need to restore
-            X_null_dropped = X.drop(self._all_null_cols, axis=1)
-            if X_null_dropped.empty:
-                return pd.DataFrame(X_t, columns=X_null_dropped.columns)
-            return pd.DataFrame(X_t, columns=X_null_dropped.columns).astype(X_null_dropped.dtypes.to_dict())
-        return pd.DataFrame(X_t)
+        if X_null_dropped.empty:
+            return pd.DataFrame(X_t, columns=X_null_dropped.columns)
+        X_t = pd.DataFrame(X_t, columns=X_null_dropped.columns)
+        if len(category_cols) > 0:
+            X_t[category_cols] = X_t[category_cols].astype('category')
+        return X_t
 
     def fit_transform(self, X, y=None):
         """Fits on X and transforms X
-
         Arguments:
             X (pd.DataFrame): Data to fit and transform
             y (pd. DataFrame): Labels to fit and transform
