@@ -1,4 +1,6 @@
 # flake8:noqa
 from .datetime_featurizer import DateTimeFeaturizer
 from .drop_null_columns import DropNullColumns
+from .text_transformer import TextTransformer
+from .lsa import LSA
 from .text_featurizer import TextFeaturizer
